@@ -6,7 +6,7 @@ test_that("SystemMetadata constructors", {
     library(datapack)
     sysmeta <- new("SystemMetadata")
     expect_that(sysmeta@serialVersion, equals(1))
-    expect_that(is.na(sysmeta@identifier), is_true())
+    expect_true(is.na(sysmeta@identifier))
     sysmeta <- new("SystemMetadata", identifier="TestId", formatId="text/csv")
     expect_that(sysmeta@identifier, equals("TestId"))
     expect_that(sysmeta@formatId, equals("text/csv"))
@@ -25,12 +25,12 @@ test_that("XML SystemMetadata parsing works", {
   expect_match(sysmeta@identifier, testid)
   expect_that(nrow(sysmeta@accessPolicy), equals(5))
   expect_match(as.character(sysmeta@accessPolicy$permission[[1]]), "read")
-  expect_that(sysmeta@archived, is_true())
+  expect_true(sysmeta@archived)
   csattrs <- xmlAttrs(xml[["checksum"]])
   expect_match(sysmeta@checksumAlgorithm, csattrs[[1]])
-  expect_that(grep("urn:node:KNB", sysmeta@preferredNodes) > 0, is_true())
-  expect_that(grep("urn:node:mnUNM1", sysmeta@preferredNodes) > 0, is_true())
-  expect_that(grep("urn:node:BADNODE", sysmeta@blockedNodes) > 0, is_true())
+  expect_true(grep("urn:node:KNB", sysmeta@preferredNodes) > 0)
+  expect_true(grep("urn:node:mnUNM1", sysmeta@preferredNodes) > 0)
+  expect_true(grep("urn:node:BADNODE", sysmeta@blockedNodes) > 0)
 })
 
 test_that("XML SystemMetadata serialization works", {
@@ -42,7 +42,7 @@ test_that("XML SystemMetadata serialization works", {
     expect_match(xmlValue(xmlRoot(xml)[["identifier"]]), testid)
     sysmeta <- parseSystemMetadata(sysmeta, xmlRoot(xml))
     expect_match(sysmeta@identifier, testid)
-    expect_that(sysmeta@archived, is_true())
+    expect_true(sysmeta@archived)
     xml <- serializeSystemMetadata(sysmeta)
     #cat(xml)
     expect_match(xml, "<d1:systemMetadata")
@@ -56,7 +56,7 @@ test_that("XML SystemMetadata serialization works", {
     sysmeta <- new("SystemMetadata")
     xml <- serializeSystemMetadata(sysmeta)
     foundObsoletes <- grep("<obsoletes>", xml, invert=TRUE)
-    expect_that(as.logical(foundObsoletes), is_true())
+    expect_true(as.logical(foundObsoletes))
     # TODO: check tree equivalence with original XML document
 })
 test_that("SystemMetadata XML constructor works", {
@@ -70,20 +70,20 @@ test_that("SystemMetadata XML constructor works", {
     expect_match(sysmeta@identifier, testid)
     expect_that(nrow(sysmeta@accessPolicy), equals(5))
     expect_match(as.character(sysmeta@accessPolicy$permission[[1]]), "read")
-    expect_that(sysmeta@archived, is_true())
+    expect_true(sysmeta@archived)
     csattrs <- xmlAttrs(xml[["checksum"]])
     expect_match(sysmeta@checksumAlgorithm, csattrs[[1]])
-    expect_that(grep("urn:node:KNB", sysmeta@preferredNodes) > 0, is_true())
-    expect_that(grep("urn:node:mnUNM1", sysmeta@preferredNodes) > 0, is_true())
-    expect_that(grep("urn:node:BADNODE", sysmeta@blockedNodes) > 0, is_true())
+    expect_true(grep("urn:node:KNB", sysmeta@preferredNodes) > 0)
+    expect_true(grep("urn:node:mnUNM1", sysmeta@preferredNodes) > 0)
+    expect_true(grep("urn:node:BADNODE", sysmeta@blockedNodes) > 0)
 })
 test_that("SystemMetadata validation works", {
     library(dataone)
     sysmeta <- new("SystemMetadata", identifier="foo", formatId="text/csv", size=59, checksum="jdhdjhfd", rightsHolder="ff")
     isValid <- validate(sysmeta)
-    expect_that(isValid, is_true())
+    expect_true(isValid)
     isValid <- validObject(sysmeta)
-    expect_that(isValid, is_true())
+    expect_true(isValid)
     sysmeta <- new("SystemMetadata", identifier="foo", checksum="jdhdjhfd", rightsHolder="ff")
     errors <- validate(sysmeta)
     expect_that(length(errors), equals(2))
